@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: ConfigDefs.pl 5028 2010-06-09 21:21:29Z sysjkf $
+#   $Id: ConfigDefs.pl 5062 2010-11-09 21:56:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -560,6 +560,7 @@ AttachmentWarningFilename	VirusWarning.txt
 AttachZipName			MessageAttachments.zip
 cleanheader			Found to be clean
 ContentSubjectText		{Dangerous Content?}
+DefaultRenamePattern		__FILENAME__.disarmed
 dirtyheader			Found to be infected
 DisarmSubjectText		{Disarmed}
 DisinfectedHeader		Disinfected
@@ -638,7 +639,7 @@ QuarantineSilent	0	no	0	yes	1
 QuarantineWholeMessage	0	no	0	yes	1
 ReplaceTNEF		2	no	0	add	1	replace	2
 sadecodebins		0	no	0	yes	1
-ScanMail		1	no	0	yes	1
+ScanMail		1	no	0	yes	1	virus	2
 SpamStars		1	no	0	yes	1
 StrictPhishing          1       no      0       yes     1
 TagPhishingSubject	0	no	0 	yes	1	start	start	end	end
