@@ -523,7 +523,7 @@ sub SQLLogging {
 #    Spam Actions              = &InternalActions
 #    High Scoring Spam Actions = &InternalActions
 # in your MailScanner.conf file, having added this code to
-#    /usr/lib/MailScanner/MailScanner/CustomConfig.pm
+#    /usr/share/MailScanner/MailScanner/CustomConfig.pm
 #
 # It uses a configuration file whose path is
 my($InternalAccountList) = '/etc/MailScanner/internal.accounts.conf';
@@ -746,7 +746,7 @@ use FileHandle;
 use Net::CIDR;
 use Socket;
 use POSIX qw(:signal_h); # For Solaris 9 SIG bug workaround
-use IO;
+use IO::Pipe;
 BEGIN { @AnyDBM_File::ISA = qw(DB_File GDBM_File NDBM_File SDBM_File) }
 use AnyDBM_File;
 
@@ -1645,7 +1645,7 @@ __DATA__
 #
 #
 
-#!/usr/bin/perl -I/usr/lib/MailScanner
+#!/usr/bin/perl -U -I/usr/share/MailScanner
 
 #
 #   MailScanner - SMTP E-Mail Virus Scanner
