@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Log.pm 4351 2008-03-17 21:06:55Z sysjkf $
+#   $Id: Log.pm 4709 2009-03-28 10:06:21Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -95,6 +95,16 @@ sub Start {
   }
 }
 
+# Re-open the logging, used after SA::initialise has nobbled it due to
+# nasty Razor code.
+sub Reset {
+  if ($LogType eq 'syslog') {
+    eval { Sys::Syslog::setlogsock($MailScanner::Log::logsock); };
+    eval { Sys::Syslog::openlog($MailScanner::Log::name, 'pid, nowait',
+                                $MailScanner::Log::facility); };
+  }
+}
+
 sub Stop {
     Sys::Syslog::closelog() if $LogType eq 'syslog';
 }
