@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: Quarantine.pm 4714 2009-04-01 16:12:10Z sysjkf $
+#   $Id: Quarantine.pm 5104 2011-09-01 09:00:23Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ use File::Temp qw ( tempfile tempdir );
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 4714 $, 10;
+$VERSION = substr q$Revision: 5104 $, 10;
 
 # Attributes are
 #
@@ -185,6 +185,8 @@ sub StoreInfections {
     
   # Create directory for this message
   $msgdir = "$todaydir/" . $message->{id};
+  $msgdir =~ /^(.*)$/;
+  $msgdir = $1;
   unless (-d $msgdir) {
     mkdir($msgdir, 0777);
     chown $uid, $gid, $msgdir if $changeowner;
