@@ -36,7 +36,7 @@ use strict 'refs';
 no  strict 'subs'; # Allow bare words for parameter %'s
 #use English; # Needed for $PERL_VERSION to work in all versions of Perl
 
-use IO;
+use IO::Pipe;
 use POSIX qw(:signal_h); # For Solaris 9 SIG bug workaround
 use DBI;
 use Compress::Zlib;
