@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SMDiskStore.pm 3768 2006-11-07 19:10:54Z sysjkf $
+#   $Id: SMDiskStore.pm 4694 2009-03-11 12:15:22Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ use MailScanner::Config;
 use vars qw($VERSION @DeletesPending);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 3768 $, 10;
+$VERSION = substr q$Revision: 4694 $, 10;
 
 # List of pending delete operations so we can clear up properly when killed
 @DeletesPending = ();
@@ -59,7 +59,7 @@ $VERSION = substr q$Revision: 3768 $, 10;
 #use vars qw($VERSION);
 #
 #### The package version, both in 1.23 style *and* usable by MakeMaker:
-#$VERSION = substr q$Revision: 3768 $, 10;
+#$VERSION = substr q$Revision: 4694 $, 10;
 
 # Attributes are
 #
@@ -354,16 +354,22 @@ sub ReadBody {
   #print STDERR "Initially read $size bytes\n";
 
   # Handle trackback -- This is the tricky one
-  if ($configwords[1] =~ /tr[au]/i) {
-    #print STDERR "Trackback:\n";
-    while (${@{$body}}[scalar(@{$body})-1] !~ /^\s*$/) {
-      print "Line is ****" . ${@{$body}}[scalar(@{$body})-1] . "****\n";
+  if ($configwords[1] =~ /tr[ua]/i) {
+    my $i;
+    for ($i=(@{$body}-1); $i>=0; $i--) {
+      last if $body->[$i] =~ /^\s*$/i;
       pop @{$body};
-      #print STDERR ".";
     }
-    #print STDERR "\n";
     return;
   }
+
+  #if ($configwords[1] =~ /tr[au]/i) {
+  #  while (${@{$body}}[scalar(@{$body})-1] !~ /^\s*$/) {
+  #    print "Line is ****" . ${@{$body}}[scalar(@{$body})-1] . "****\n";
+  #    pop @{$body};
+  #  }
+  #  return;
+  #}
   
   # Handle continue
   if ($configwords[1] =~ /con/i) {
