@@ -2,7 +2,7 @@
 #   MailScanner - SMTP E-Mail Virus Scanner
 #   Copyright (C) 2002  Julian Field
 #
-#   $Id: SweepOther.pm 5065 2010-11-13 15:14:59Z sysjkf $
+#   $Id: SweepOther.pm 5098 2011-06-25 20:11:06Z sysjkf $
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ use POSIX qw(:signal_h setsid); # For Solaris 9 SIG bug workaround
 use vars qw($VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = substr q$Revision: 5065 $, 10;
+$VERSION = substr q$Revision: 5098 $, 10;
 
 # Attributes are
 #
@@ -345,7 +345,11 @@ sub ScanBatch {
                 # They have supplied the replacement text, now in $allowdeny
                 $newname = $attach;
                 # This lets them put things like $1 and $2 in the RHS.
-                eval '$newname =~ s/'.$regexp.'/'.$allowdeny.'/i';
+                $regexp =~ /^(.*)$/;
+                $regexp = $1;
+                $allowdeny =~ /^(.*)$/;
+                $allowdeny = $1;
+                eval '$newname =~ s/'.$regexp.'/'.$allowdeny.'/i'; # TAINT
                 #$newname =~ s/$regexp/$allowdeny/is;
               } else {
                 # No replacement text, so use the default rename pattern
