@@ -230,6 +230,9 @@ sub ExternalDecoder {
   # Create the subdir to unpack it into
   #my $unpackdir = "tnef.$$";
   my $unpackdir = tempdir("tnefXXXXXX", DIR => $dir);
+  # This line shouldn't be here any more! $dir =~ s,^.*/,,;
+  # And leave $unpackdir as the full path.
+  #$unpackdir = $message->MakeNameSafe($unpackdir, $dir);
   unless (-d $unpackdir) {
     MailScanner::Log::WarnLog("Trying to unpack %s in message %s, could not create subdirectory %s, failed to unpack TNEF message", $tnefname, $message->{id},
                               "$unpackdir");
@@ -318,10 +321,10 @@ sub ExternalDecoder {
 
     unless (MailScanner::Config::Value('replacetnef',$message) =~ /[12]/) {
       # Just need to move all the unpacked files into the main attachments dir
-      my $dirh = new DirHandle "$$unpackdir";
+      my $dirh = new DirHandle "$unpackdir";
       return 0 unless defined $dirh;
       while (defined(my $unpacked = $dirh->read)) {
-        next unless -f "$$unpackdir/$unpacked";
+        next unless -f "$unpackdir/$unpacked";
         # Add a 't' to the safename to mark it as a tnef member.
         my $safe = $message->MakeNameSafe('t'.$unpacked, $dir);
         # This will cause big problems as $safe has a type, and shouldn't!
@@ -342,7 +345,7 @@ sub ExternalDecoder {
       }
       # The following may result in a warning from a virus scanner that
       # tries to lstat the directory, but it was empty so it can be ignored.
-      rmdir "$$unpackdir"; # Directory should be empty now
+      rmdir "$unpackdir"; # Directory should be empty now
       return 1;
     }
     #print STDERR "In TNEF External Decoder\n";
